local VERSION = tonumber(("$Revision: 54421 $"):match("%d+"))

if uab.revision < VERSION then
	uab.version = "r" .. VERSION
	uab.revision = VERSION
	uab.date = ("$Date: 2007-11-12 16:21:36 -0500 (Mon, 12 Nov 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

uab.classes.MacroAction = uab.mixins.aceOO.Class(uab.classes.BaseAction)

function uab.classes.MacroAction.prototype:init(data)
	uab.classes.MacroAction.super.prototype.init(self)
	
	self.data = data
    self.text = self.data.name

	self:SetIcon()
end

function uab.classes.MacroAction.prototype:GetAttributes()
    local attribs = {}

    attribs["type"] = "macro"
    attribs["macro"] = self.text
    
    return attribs
end

function uab.classes.MacroAction.prototype:GetClassName()
	return "ItemAction"
end

-- Override
function uab.classes.MacroAction.prototype:GetCount()
    local spell
    local rank

    if GetMacroSpell then
        spell, rank = GetMacroSpell(self.data.name)
    end
    
    if spell then
        return uab.classes.SpellAction.GetCount(spell, rank)
    elseif GetMacroItem then
        local itemText
        local itemLink
    
        if GetMacroItem then
            itemText, itemLink = GetMacroItem(self.data.name)
        end
        
        if itemText or itemLink then
            return uab.classes.ItemAction.GetCount(itemText, itemLink)
        end
    end
end

function uab.classes.MacroAction.prototype:IsActive()
    local spell
    local rank

    if GetMacroSpell then
        spell, rank = GetMacroSpell(self.data.name)
    end
    
    if spell then
        return uab.classes.SpellAction.IsActive(spell, rank)
    elseif GetMacroItem then
        local item
        local link
        
        item, link = GetMacroItem(self.data.name)
        if item then
            return IsCurrentItem(item)
        elseif link then
            return IsCurrentItem(link)
        end
    end
end

function uab.classes.MacroAction.prototype:IsUsable()
    local spell
    local rank

    if GetMacroSpell then
        spell, rank = GetMacroSpell(self.data.name)
    end
    
    if spell then
        return IsUsableSpell(spell)
    elseif GetMacroItem then
        local item
        local link
        
        item, link = GetMacroItem(self.data.name)
        if item then
            return IsUsableItem(item)
        elseif link then
            return IsUsableItem(link)
        end
    end
end

function uab.classes.MacroAction.prototype:ShowTooltip(frame)
    --[[
    Need to find the referenced item.  Look in the player's inventory first.
    If not there, look in the player's bags.
    --]]

    GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
    GameTooltip:SetBackdropColor(0.1, 0.1, 0.1, 0.8)

    for id = GetNumMacros(), 1, -1 do
        local name, texture, _, _ = GetMacroInfo(id)
        
        if name == self.data.name then
            GameTooltip:SetText(self.data.name)
            return
        end
    end
end

-- Override
function uab.classes.MacroAction.prototype:GetCooldown()
    local spell
    local rank

    if GetMacroSpell then
        spell, rank = GetMacroSpell(self.data.name)
    end
    
    if spell then
        return uab.classes.SpellAction.GetCooldown(spell, rank)
    elseif GetMacroItem then
        local item
        local link
        
        item, link = GetMacroItem(self.data.name)
        if item then
            return GetItemCooldown(item)
        elseif link then
            return GetItemCooldown(link)
        end
    end
end

--[[---------------------------------------------------------------------------
Helper methods, to be used only by the class itself
-----------------------------------------------------------------------------]]

function uab.classes.MacroAction.prototype:SetIcon()
    self.icon = self.data.icon
    
    if not self.icon then
    	--[[
    	Need to find the referenced macro based on the name of the macro.
    	--]]

        for id = GetNumMacros(), 1, -1 do
            local name, texture, _, _ = GetMacroInfo(id)
            
            if name == self.data.name then
                self.icon = texture
                break
            end
        end
    end
    
    self.data.icon = self.icon
end

